%% Estimation of shares of income accruing to different deciles and percentiles of the population after changing the tax unit from households to individuals
%
%
%% 1. Preliminaries 
close all; clear all;
currentfolder=pwd;
% Path to load data
loadpath=[currentfolder,'/data'];

%% 2. Loads data
disp('Loads data');

cd(loadpath);
 [tabulation_singles] = xlsread('singles','Tabulation'); %thresholds, singles
  tab1.thr = tabulation_singles(:,1); %thresholds
  tab1.p   = tabulation_singles(:,2); %number of taxpayers
  tab1.b   = tabulation_singles(:,3); %inverted Pareto coefficients
     T     = length(tab1.thr); %number of thresholds in the tax tabulation
  [y_av1]  = xlsread('singles','Average income'); %average income
   [N1]    = xlsread('singles','Number'); %total number of singles

 [tabulation_families] = xlsread('couples','Tabulation'); %thresholds, singles
  tab2.thr = tabulation_families(:,1); %thresholds
  tab2.p   = tabulation_families(:,2); %number of taxpayers
  tab2.b   = tabulation_families(:,3); %inverted Pareto coefficients
     T     = length(tab2.thr); %number of thresholds in the tax tabulation
  [y_av2]  = xlsread('couples','Average income'); %average income
   [N2]    = xlsread('couples','Number'); %total number of couples
   
clear tabulation_singles tabulation_families;
cd(currentfolder);

%% 3.1. Estimates the quantile function - Singles
disp('Estimates the quantile function - Singles');

Xn = 10000000; %number of nodes
nodes = linspace(0,1,Xn)';

[Q1,p01] = quantile(tab1.thr,tab1.p,tab1.b,y_av1,nodes);

%% 3.2. Estimates the quantile function - Couples
disp('Estimates the quantile function - Couples');

[Q2,p02] = quantile(tab2.thr,tab2.p,tab2.b,y_av2,nodes);

%% 4.1. Approximates the PDF - Singles
nz1=length(Q1)-nnz(Q1);

h1 = Q1(nz1+1:Xn)-Q1(nz1:Xn-1);
f1 = (pp1(nz1+1:Xn)-pp1(nz1:Xn-1))./h1;

%% 4.2. Approximates the PDF - Singles
nz2=length(Q2)-nnz(Q2);

h2 = Q2(nz2+1:Xn)-Q2(nz2:Xn-1);
f2 = (pp1(nz2+1:Xn)-pp1(nz2:Xn-1))./h2;

%% 5. Merges the two distributions
p0=(N1*p01+2*N2*p02)/(N1+2*N2);

nodes_fin = linspace(p0,1,Xn)';
f = (N1*interp1(Q1(nz1:Xn-1),f1,nodes_fin,'linear','extrap') + N2*2*interp1(Q2(nz1:Xn-1),f2,2*nodes_fin,'linear','extrap'))/(N1+2*N2);

h = nodes_fin(2:Xn)-nodes_fin(1:Xn-1);
F = p0+cumsum(h.*f(1:Xn-1));

%% 6. Gives the results

perc = [0.5, 0.9, 0.95, 0.99]
results = interp1(F,nodes_fin(1:Xn-1),perc,'linear')
