%%

%% 1. Preliminaries
close all; clear all;

currentfolder=pwd;
% Path to load data
loadpath=[currentfolder,'/rawdata/gumbel_allfiles'];
param_path=[currentfolder,'/rawdata/gumbel_allfiles/parameters'];

% Number of taxpayers to be generated
Npop = 1000000;

cd(param_path);
T = xlsread('parameters.xlsx','theta')';

%% 2. Loads data
disp('Loading data...');

cd(loadpath);
dd = dir('*.xls*');

inputsNames = {dd.name};

n = numel(inputsNames);

for ii = 1:n
  
disp(inputsNames{ii})

%try
cd(loadpath);

  [rawdata_k] = xlsread(inputsNames{ii},'Capital');
   rawdata_k  = rawdata_k(2:end,:);
  [rawdata_l] = xlsread(inputsNames{ii},'Labor');
   rawdata_l  = rawdata_l(2:end,:);
    
filename_thr = strcat('top_thr_',strtok(inputsNames(ii),'.'),'.csv');
filename_av = strcat('top_av_',strtok(inputsNames(ii),'.'),'.csv');


codespath=[currentfolder,'/codes'];
cd(codespath);
[raw_k.thr,raw_k.p,raw_k.b,yk_av,dirac_k,neg_k] = inputs_check(rawdata_k);
[raw_l.thr,raw_l.p,raw_l.b,yl_av,dirac_l,neg_l] = inputs_check(rawdata_l);

if ~(length(dirac_k)==1)
      p0_k  = dirac_k(2);
	dirac_k = dirac_k(1);
else
    dirac_k = 0;
    p0_k = NaN;
end

if ~(length(dirac_l)==1)
      p0_l  = dirac_l(2);
	dirac_l = dirac_l(1);
else
    dirac_l = 0;
    p0_l = NaN;
end
    
if ~(length(neg_k)==1)
	thr_neg_k = neg_k(1);
	p_neg_k = neg_k(2);
	av_neg_k = neg_k(3);
else
    thr_neg_k = 0;
	p_neg_k = 0;
	av_neg_k = 0;
end

if ~(length(neg_l)==1)
	thr_neg_l = neg_l(1);
	p_neg_l = neg_l(2);
	av_neg_l = neg_l(3);
else
    thr_neg_l = 0;
	p_neg_l = 0;
	av_neg_l = 0;
end
    
clear rawdata_k rawdata_l;
cd(currentfolder);

%% 3. Defines g-percentiles
disp('Defining g-percentiles...');

gp1 = linspace(0,0.99,100);
gp2 = linspace(0.991,0.999,9);
gp3 = linspace(0.9991,0.9999,9);
gp4 = linspace(0.99991,0.99999,9);

gperc = [gp1,gp2,gp3,gp4]';


%% 3. Gumbel copula
disp('Generating the Gumbel copula...');

u0 = (0:(10000000-1))'/(10000000-1);

cd(codespath);
[yk_pop0,~] = quantile(shift_p(u0(u0(:)>=p_neg_k),p_neg_k),shift_thr(raw_k.thr,dirac_k),shift_p(raw_k.p,p_neg_k),shift_b(raw_k.thr,raw_k.b,dirac_k),shift_av(yk_av,dirac_k,p_neg_k,av_neg_k),shift_p(p_neg_k+p0_k,p_neg_k));
yk_pop0 = dirac_k+yk_pop0;

[yl_pop0,~] = quantile(shift_p(u0(u0(:)>=p_neg_l),p_neg_l),shift_thr(raw_l.thr,dirac_l),shift_p(raw_l.p,p_neg_l),shift_b(raw_l.thr,raw_l.b,dirac_l),shift_av(yl_av,dirac_l,p_neg_l,av_neg_l),shift_p(p_neg_l+p0_l,p_neg_l));
yl_pop0 = dirac_l+yl_pop0;

for tt = 1:length(T)
cd(codespath);

theta = T(tt)

%v = rand(Npop,2);

%w = -theta*v(:,2)./lambertw(-theta*exp(-theta)*v(:,2));

%u = zeros(Npop,2);
%u(:,1) = exp(v(:,1).^(1/theta)*log(w));
%u(:,2) = exp((1-v(:,1)).^(1/theta)*log(w));

u = copularnd('Gumbel',theta,Npop);

%% 4. Simulates the population
disp('Simulating the population...');

yk_pop = qinterp1(u0,yk_pop0,u(:,1));
yl_pop = qinterp1(u0,yl_pop0,u(:,2));

A = ones(size(yk_pop));

sum(A(isnan(yk_pop)))
sum(A(isnan(yl_pop)))

y_pop = yk_pop+yl_pop;
[y_pop,I] = sort(y_pop);
yk_pop = yk_pop(I);
yl_pop = yl_pop(I);

sum(A(isnan(yk_pop)))
sum(A(isnan(yl_pop)))
sum(A(isnan(y_pop)))

pp = (0:(length(y_pop)-1))/(length(y_pop)-1);

br = bracket(gperc,pp');

alpha = zeros(127,1);
for jj=1:127
    alpha(jj)=sum(yk_pop(br==jj))/sum(y_pop(br==jj));
end


av = flip(cumsum(flip(y_pop))./(1:length(y_pop))');

thr = interp1(pp,y_pop,gperc);
av = interp1(pp,av,gperc);
B = av./thr;
gperc100 = 100*gperc;
table = [gperc100,thr,av,B,alpha];

filename = strcat('gperc_',strtok(inputsNames(ii),'.'),'_',num2str(theta),'.csv');

outputpath=[currentfolder,'/output/gumbel_allfiles'];
cd(outputpath);

header = {'p','thr','ytop','b','alpha'};

fileID = fopen(filename{1}, 'w');
if fileID == -1; error('Cannot open file: %s', filename); end
fprintf(fileID, '%s,', header{1:end-1});
fprintf(fileID, '%s\n', header{end});
fprintf(fileID, '%.3f,%.4f,%.4f,%.4f,%.4f\n', table');
fclose(fileID);


% Capital income
cd(codespath);

yk_pop = sort(yk_pop);
av_k = flip(cumsum(flip(yk_pop))./(1:length(yk_pop))');

thr_k = qinterp1(pp,yk_pop,gperc);
av_k = qinterp1(pp,av_k,gperc);
B_k = av_k./thr_k;
gperc100 = 100*gperc;
table = [gperc100,thr_k,av_k,B_k];

filename = strcat('gperc_k_',strtok(inputsNames(ii),'.'),'_',num2str(theta),'.csv');

outputpath=[currentfolder,'/output/gumbel_allfiles'];
cd(outputpath);

header = {'p','thr','ytop','b'};

fileID = fopen(filename{1}, 'w');
if fileID == -1; error('Cannot open file: %s', filename); end
fprintf(fileID, '%s,', header{1:end-1});
fprintf(fileID, '%s\n', header{end});
fprintf(fileID, '%.3f,%.4f,%.4f,%.4f\n', table');
fclose(fileID);


% Labor income
cd(codespath);

yl_pop = sort(yl_pop);
av_l = flip(cumsum(flip(yl_pop))./(1:length(yl_pop))');

thr_l = qinterp1(pp,yl_pop,gperc);
av_l = qinterp1(pp,av_l,gperc);
B_l = av_l./thr_l;
gperc100 = 100*gperc;
table = [gperc100,thr_l,av_l,B_l];

filename = strcat('gperc_l_',strtok(inputsNames(ii),'.'),'_',num2str(theta),'.csv');

outputpath=[currentfolder,'/output/gumbel_allfiles'];
cd(outputpath);

header = {'p','thr','ytop','b'};

fileID = fopen(filename{1}, 'w');
if fileID == -1; error('Cannot open file: %s', filename); end
fprintf(fileID, '%s,', header{1:end-1});
fprintf(fileID, '%s\n', header{end});
fprintf(fileID, '%.3f,%.4f,%.4f,%.4f\n', table');
fclose(fileID);

end



%catch
%    continue
%end
end