/*******Stata code generating unified Stata file gperc_yf_China.dta (distribution of pretax fiscal income among equal-split adults) using raw gperc files simulated via generalized Pareto simulations*********/
/*****total China: additive urban + rural ****/
/***be careful: run this programme only after adding urban and rural distributions in MatLab***/


#delimit;
clear;
set more off;

cd "D:\Dropbox\WIDChina\PYZ2016DistributionSeries\";



/*******************importing gperc China series for pretax fiscal income 1980-2014******************/
forvalues year=1978/2015
{;
import delimited SimulationTwoDimMatlab\additive\output\multiyear\China_`year'.csv, clear; 
gen year=`year';
save StataFiles/temp/gperc_yf_China_`year'.dta, replace;
clear;
};
/*****merging all year files*/
use StataFiles/temp/gperc_yf_China_1978.dta;
forvalues year=1979/2015 
{;
append using StataFiles/temp/gperc_yf_China_`year'.dta;
};
sort year p;
save StataFiles/gperc_yf_China.dta, replace;
clear;
/*****rearranging variables so as to fit DINA template tables and checking inconsistencies*/
use StataFiles/gperc_yf_China.dta, clear;
replace p=1000*p;
replace p=int(p);
rename thr ythr;
rename china_urbanxls shurban;
gsort year p;
gen yint=ytop if p==99999;
replace yint=((100000-p)*ytop-(100000-p[_n+1])*ytop[_n+1])/(p[_n+1]-p) if p<99999;
gen f=p[_n+1]-p if p<99999;
replace f=1 if p==99999;
keep year p f ythr yint ytop b shurban;
sort year p f ythr yint ytop b shurban;
order year p f ythr yint ytop b shurban;
/***consistency check*/
gen check=0;
replace check=1 if yint<ythr | (yint>ythr[_n+1] & p<99999);
/*check: no inconsistency*/
/*ta check;*/
replace yint=0.5*ythr+0.5*ythr[_n+1] if check==1;
drop check;
gsort year -p;
replace ytop=yint if p==99999;
replace ytop=(f*yint+(100000-p[_n-1])*ytop[_n-1])/(100000-p) if p<99999;
gsort year p;
save StataFiles/gperc_yf_China.dta, replace; 


/**********adjusting average income********************/
use StataFiles/temp/yfu_China.dta, clear; 
merge 1:1 year using StataFiles/temp/yfr_China.dta, nogen;
gen yf=(adultpopu*yfu+adultpopr*yfr)/(adultpopu+adultpopr); 
save StataFiles/temp/yf_China.dta, replace; 
use StataFiles/gperc_yf_China.dta, clear;
merge m:1 year using StataFiles/temp/yf_China.dta, nogen; 
sort year;
by year: egen yfc=total(f*yint);
replace yfc=yfc/100000;
gen ratio=yf/yfc;
replace ythr=ythr*ratio;
replace yint=yint*ratio;
replace ytop=ytop*ratio;
replace b=ytop/ythr;
keep year p f ythr yint ytop b;
sort year p f ythr yint ytop b;
order year p f ythr yint ytop b;
save StataFiles/gperc_yf_China.dta, replace; 



/***************extracting table 1yf: summary statistics*/
use StataFiles/gperc_yf_China.dta, clear;
sort year p;
gen p0=0 if p==0;
replace p0=p/1000+(yint/(ythr[_n+1]-ythr))*f/1000 if ythr==0 & ythr[_n+1]>0 & year[_n+1]==year;
keep if p==0 | p==10000 | p==20000 | p==30000 | p==40000 | p==50000 | p==60000 | p==70000 | p==80000 | p==90000 | p==99000 | p==99900 | p==99990 | p==99999;
sort year p; 
gen ymean=ytop if p==0;
gen bottom10=1-0.9*ytop[_n+1]/ytop if p==0;
gen bottom50=1-0.5*ytop[_n+5]/ytop if p==0;
gen top10=0.1*ytop[_n+9]/ytop if p==0;
gen middle40=1-top10-bottom50 if p==0;
gen top1=0.01*ytop[_n+10]/ytop if p==0;
gen top01=0.001*ytop[_n+11]/ytop if p==0;
gen top001=0.0001*ytop[_n+12]/ytop if p==0;
gen top0001=0.00001*ytop[_n+13]/ytop if p==0;
gen p10=ythr[_n+1]/ymean if p==0;
gen p50=ythr[_n+5]/ymean if p==0;
gen p90=ythr[_n+9]/ymean if p==0;
gen p99=ythr[_n+10]/ymean if p==0;
gen p999=ythr[_n+11]/ymean if p==0;
gen p9999=ythr[_n+12]/ymean if p==0;
gen p99999=ythr[_n+13]/ymean if p==0;
gen b10=ytop[_n+1]/ythr[_n+1] if p==0;
gen b50=ytop[_n+5]/ythr[_n+5] if p==0;
gen b90=ytop[_n+9]/ythr[_n+9] if p==0;
gen b99=ytop[_n+10]/ythr[_n+10] if p==0;
gen b999=ytop[_n+11]/ythr[_n+11] if p==0;
gen b9999=ytop[_n+12]/ythr[_n+12] if p==0;
gen b99999=ytop[_n+13]/ythr[_n+13] if p==0;
gen p20=ythr[_n+2]/ymean if p==0;
gen p30=ythr[_n+3]/ymean if p==0;
gen p40=ythr[_n+4]/ymean if p==0;
gen p60=ythr[_n+6]/ymean if p==0;
gen p70=ythr[_n+7]/ymean if p==0;
gen p80=ythr[_n+8]/ymean if p==0;
gen p1020=(0.9*ytop[_n+1]-0.8*ytop[_n+2])/(0.1*ymean);
gen p2030=(0.8*ytop[_n+2]-0.7*ytop[_n+3])/(0.1*ymean);
gen p3040=(0.7*ytop[_n+3]-0.6*ytop[_n+4])/(0.1*ymean);
gen p4050=(0.6*ytop[_n+4]-0.5*ytop[_n+5])/(0.1*ymean);
gen p5060=(0.5*ytop[_n+5]-0.4*ytop[_n+6])/(0.1*ymean);
gen p6070=(0.4*ytop[_n+6]-0.3*ytop[_n+7])/(0.1*ymean);
gen p7080=(0.3*ytop[_n+7]-0.2*ytop[_n+8])/(0.1*ymean);
gen p8090=(0.2*ytop[_n+8]-0.1*ytop[_n+9])/(0.1*ymean);
keep if p==0;
keep year ymean bottom10 bottom50 middle40 top10 top1 top01 top001 top0001 p0 p10 p50 p90 p99 p999 p9999 p99999 b10 b50 b90 b99 b999 b9999 b99999 p20 p30 p40 p60 p70 p80 p1020 p2030 p3040 p4050 p5060 p6070 p7080 p8090;
order year ymean bottom10 bottom50 middle40 top10 top1 top01 top001 top0001 p0 p10 p50 p90 p99 p999 p9999 p99999 b10 b50 b90 b99 b999 b9999 b99999 p20 p30 p40 p60 p70 p80 p1020 p2030 p3040 p4050 p5060 p6070 p7080 p8090;
save StataFiles/tables/table1yf.dta, replace;
export excel using StataFiles/tables/table1yf.xlsx, firstrow(variables) replace;


/*******************extracting table 2yf: detailed statistics*/
forvalues year=1978/2015         
{;
use StataFiles/gperc_yf_China.dta, clear;
keep if year==`year';
rename ythr ythr_`year';
rename ytop ytop_`year';
rename b b_`year';
keep p ythr_`year' ytop_`year' b_`year';
order p ythr_`year' ytop_`year' b_`year';
sort p;
save StataFiles/temp/g_percf_`year'.dta, replace;
clear;
};
use StataFiles/temp/g_percf_1978.dta;
forvalues year=1979/2015         
{;
merge 1:1 p using StataFiles/temp/g_percf_`year'.dta, nogen;
};
save Statafiles/tables/table2yf.dta, replace;
export excel using Statafiles/tables/table2yf.xlsx, firstrow(variables) replace;

