/*******new Stata code using wealth distribution output from WID.world gpinter with survey+Hurun annual data, and then exporting ynf + yf data for gpinter copula computations*****/

#delimit;
clear;
set more off;

cd "D:\Dropbox\WIDChina\PYZ2017DistributionSeries\";


/******************importing all averages series****/
import excel Tabulations/rawdata_bysheet_urbanChina_raw.xlsx, sheet("Parameters") cellrange(A11:d49) firstrow clear;
save StataFiles/temp/yfu_China.dta, replace;
import excel Tabulations/rawdata_bysheet_ruralChina_raw.xlsx, sheet("Parameters") cellrange(A11:d49) firstrow clear;
save StataFiles/temp/yfr_China.dta, replace;
import excel Tabulations/rawdata_bysheet_China_wealth.xlsx, sheet("Parameters") cellrange(A11:h49) firstrow clear;
save StataFiles/temp/w_China.dta, replace;
sort year;
merge 1:1 year using StataFiles/temp/yfu_China.dta, nogen;
merge 1:1 year using StataFiles/temp/yfr_China.dta, nogen;
gen ypri0=yf+ynf;
gen ypub0=y-ypri0;
gen ypri=ypri0-it+ct;
gen ypub=ypub0+it-ct;
gen ys=(adultpopu*ysu+adultpopr*ysr)/adultpop;
gen yu=y*yfu/yf;
gen wu=w*yfu/yf;
gen yr=y*yfr/yf;
gen wr=w*yfr/yf;
order year adultpop y w yf ys ynf ypri ypub ypri0 ypub0 it ct adultpopu yu wu yfu ysu adultpopr yr wr yfr ysr;
save StataFiles/averages_China.dta, replace;
clear;

/*******************importing gperc China series for wealth 1995 and 2002-2015******************/
import excel Gpinter\WealthTabulations\BenchmarkWealthSeries.xlsx, sheet("China, 1995") firstrow;
rename Percentiles p;
rename Threshold thr;
rename InvertedParetocoefficient b;
rename Topaverage ytop;
drop Topshare;
gen year=1995;
save StataFiles/temp/gperc_w_China_1995.dta, replace;
clear;
forvalues year=2002/2015 
{;
import excel Gpinter\WealthTabulations\BenchmarkWealthSeries.xlsx, sheet("China, `year'") firstrow;
rename Percentiles p;
rename Threshold thr;
rename InvertedParetocoefficient b;
rename Topaverage ytop;
drop Topshare;
gen year=`year';
save StataFiles/temp/gperc_w_China_`year'.dta, replace;
clear;
};


/*****merging all year files*/
use StataFiles/temp/gperc_w_China_1995.dta;
forvalues year=2002/2015 
{;
append using StataFiles/temp/gperc_w_China_`year'.dta;
};
sort year p;
save StataFiles/gperc_w_China.dta, replace;
clear;

/*****rearranging variables so as to fit DINA template tables and checking inconsistencies*/
use StataFiles/gperc_w_China.dta, clear;
gsort year p;
replace p=100000*p;
replace p=int(p);
replace p=99992 if p==99991 & p[_n-1]==99991;
replace p=99997 if p==99996 & p[_n-1]==99996;
rename thr ythr;
gsort year p;
gen yint=ytop if p==99999;
replace yint=((100000-p)*ytop-(100000-p[_n+1])*ytop[_n+1])/(p[_n+1]-p) if p<99999;
gen f=p[_n+1]-p if p<99999;
replace f=1 if p==99999;
keep year p f ythr yint ytop b;
sort year p f ythr yint ytop b;
order year p f ythr yint ytop b;
/***consistency check*/
gen check=0;
replace check=1 if yint<ythr | (yint>ythr[_n+1] & p<99999);
/*check: no inconsistency*/
/*ta check;*/
replace yint=0.5*ythr+0.5*ythr[_n+1] if check==1;
drop check;
gsort year -p;
replace ytop=yint if p==99999;
replace ytop=(f*yint+(100000-p[_n-1])*ytop[_n-1])/(100000-p) if p<99999;
gsort year p;
save StataFiles/gperc_w_China.dta, replace; 


/*****imputing missing years: 1978-1994 and 1996-2001***/
forvalues year=1978/1994
{;
use StataFiles/gperc_w_China.dta, clear;
keep if year==1995;
replace year=`year';
append using StataFiles/gperc_w_China.dta;
save StataFiles/gperc_w_China.dta, replace;
};
forvalues year=1996/2001
{;
use StataFiles/gperc_w_China.dta, clear;
keep if year==1995 | year==2002;
replace year=`year' if year==1995;
gen c=(2002-`year')/7;
replace ythr=c*ythr+(1-c)*ythr[_n+127] if year==`year';
replace yint=c*yint+(1-c)*yint[_n+127] if year==`year';
drop if year==2002;
drop ytop b c;
gsort -p;
gen ytop=yint if p==99999;
replace ytop=(f*yint+(100000-p[_n-1])*ytop[_n-1])/(100000-p) if p<99999;
append using StataFiles/gperc_w_China.dta;
save StataFiles/gperc_w_China.dta, replace;
};


/**********adjusting average wealth********************/
/*****total China****/
use StataFiles/gperc_w_China.dta, clear;
merge m:1 year using StataFiles/averages_China.dta, nogen; 
sort year;
by year: egen w2=total(f*yint);
replace w2=w2/100000;
gen ratio=w/w2;
replace ythr=ythr*ratio;
replace yint=yint*ratio;
replace ytop=ytop*ratio;
replace b=ytop/ythr;
keep year p f ythr yint ytop b;
sort year p f ythr yint ytop b;
order year p f ythr yint ytop b;
/***consistency check*/
gen check=0;
replace check=1 if yint<ythr | (yint>ythr[_n+1] & p<99999);
/*check: no inconsistency*/
/*ta check;*/
replace yint=0.5*ythr+0.5*ythr[_n+1] if check==1;
drop check;
save StataFiles/gperc_w_China.dta, replace;
merge m:1 year using StataFiles/temp/w_China.dta, nogen; 
sort year;
by year: egen w2=total(f*yint);
replace w2=w2/100000;
gen ratio=ynf/w2;
replace ythr=ythr*ratio;
replace yint=yint*ratio;
replace ytop=ytop*ratio;
replace b=ytop/ythr;
keep year p f ythr yint ytop b;
sort year p f ythr yint ytop b;
order year p f ythr yint ytop b;
save StataFiles/gperc_ynf_China.dta, replace;
/*****urban China***/ 
use StataFiles/gperc_w_China.dta, clear;
merge m:1 year using StataFiles/averages_China.dta, nogen; 
sort year;
by year: egen w2=total(f*yint);
replace w2=w2/100000;
gen ratio=wu/w2;
replace ythr=ythr*ratio;
replace yint=yint*ratio;
replace ytop=ytop*ratio;
replace b=ytop/ythr;
keep year p f ythr yint ytop b;
sort year p f ythr yint ytop b;
order year p f ythr yint ytop b;
save StataFiles/gperc_w_UrbanChina.dta, replace;
merge m:1 year using StataFiles/averages_China.dta, nogen; 
sort year;
by year: egen w2=total(f*yint);
replace w2=w2/100000;
gen ratio=(ynf*yfu/yf)/w2;
replace ythr=ythr*ratio;
replace yint=yint*ratio;
replace ytop=ytop*ratio;
replace b=ytop/ythr;
keep year p f ythr yint ytop b;
sort year p f ythr yint ytop b;
order year p f ythr yint ytop b;
save StataFiles/gperc_ynf_UrbanChina.dta, replace;
/*****rural China***/ 
use StataFiles/gperc_w_China.dta, clear;
merge m:1 year using StataFiles/averages_China.dta, nogen; 
sort year;
by year: egen w2=total(f*yint);
replace w2=w2/100000;
gen ratio=wr/w2;
replace ythr=ythr*ratio;
replace yint=yint*ratio;
replace ytop=ytop*ratio;
replace b=ytop/ythr;
keep year p f ythr yint ytop b;
sort year p f ythr yint ytop b;
order year p f ythr yint ytop b;
save StataFiles/gperc_w_RuralChina.dta, replace;
merge m:1 year using StataFiles/averages_China.dta, nogen; 
sort year;
by year: egen w2=total(f*yint);
replace w2=w2/100000;
gen ratio=(ynf*yfr/yf)/w2;
replace ythr=ythr*ratio;
replace yint=yint*ratio;
replace ytop=ytop*ratio;
replace b=ytop/ythr;
keep year p f ythr yint ytop b;
sort year p f ythr yint ytop b;
order year p f ythr yint ytop b;
save StataFiles/gperc_ynf_RuralChina.dta, replace;


/***************extracting table 1w: summary statistics*/
use StataFiles/gperc_w_China.dta, clear;
sort year p;
gen p0=0 if p==0;
replace p0=p/1000+(yint/(ythr[_n+1]-ythr))*f/1000 if ythr==0 & ythr[_n+1]>0 & year[_n+1]==year;
keep if p==0 | p==10000 | p==20000 | p==30000 | p==40000 | p==50000 | p==60000 | p==70000 | p==80000 | p==90000 | p==99000 | p==99900 | p==99990 | p==99999;
sort year p; 
gen ymean=ytop if p==0;
gen bottom10=1-0.9*ytop[_n+1]/ytop if p==0;
gen bottom50=1-0.5*ytop[_n+5]/ytop if p==0;
gen top10=0.1*ytop[_n+9]/ytop if p==0;
gen middle40=1-top10-bottom50 if p==0;
gen top1=0.01*ytop[_n+10]/ytop if p==0;
gen top01=0.001*ytop[_n+11]/ytop if p==0;
gen top001=0.0001*ytop[_n+12]/ytop if p==0;
gen top0001=0.00001*ytop[_n+13]/ytop if p==0;
gen p10=ythr[_n+1]/ymean if p==0;
gen p50=ythr[_n+5]/ymean if p==0;
gen p90=ythr[_n+9]/ymean if p==0;
gen p99=ythr[_n+10]/ymean if p==0;
gen p999=ythr[_n+11]/ymean if p==0;
gen p9999=ythr[_n+12]/ymean if p==0;
gen p99999=ythr[_n+13]/ymean if p==0;
gen b10=ytop[_n+1]/ythr[_n+1] if p==0;
gen b50=ytop[_n+5]/ythr[_n+5] if p==0;
gen b90=ytop[_n+9]/ythr[_n+9] if p==0;
gen b99=ytop[_n+10]/ythr[_n+10] if p==0;
gen b999=ytop[_n+11]/ythr[_n+11] if p==0;
gen b9999=ytop[_n+12]/ythr[_n+12] if p==0;
gen b99999=ytop[_n+13]/ythr[_n+13] if p==0;
gen p20=ythr[_n+2]/ymean if p==0;
gen p30=ythr[_n+3]/ymean if p==0;
gen p40=ythr[_n+4]/ymean if p==0;
gen p60=ythr[_n+6]/ymean if p==0;
gen p70=ythr[_n+7]/ymean if p==0;
gen p80=ythr[_n+8]/ymean if p==0;
gen p1020=(0.9*ytop[_n+1]-0.8*ytop[_n+2])/(0.1*ymean);
gen p2030=(0.8*ytop[_n+2]-0.7*ytop[_n+3])/(0.1*ymean);
gen p3040=(0.7*ytop[_n+3]-0.6*ytop[_n+4])/(0.1*ymean);
gen p4050=(0.6*ytop[_n+4]-0.5*ytop[_n+5])/(0.1*ymean);
gen p5060=(0.5*ytop[_n+5]-0.4*ytop[_n+6])/(0.1*ymean);
gen p6070=(0.4*ytop[_n+6]-0.3*ytop[_n+7])/(0.1*ymean);
gen p7080=(0.3*ytop[_n+7]-0.2*ytop[_n+8])/(0.1*ymean);
gen p8090=(0.2*ytop[_n+8]-0.1*ytop[_n+9])/(0.1*ymean);
keep if p==0;
keep year ymean bottom10 bottom50 middle40 top10 top1 top01 top001 top0001 p0 p10 p50 p90 p99 p999 p9999 p99999 b10 b50 b90 b99 b999 b9999 b99999 p20 p30 p40 p60 p70 p80 p1020 p2030 p3040 p4050 p5060 p6070 p7080 p8090;
order year ymean bottom10 bottom50 middle40 top10 top1 top01 top001 top0001 p0 p10 p50 p90 p99 p999 p9999 p99999 b10 b50 b90 b99 b999 b9999 b99999 p20 p30 p40 p60 p70 p80 p1020 p2030 p3040 p4050 p5060 p6070 p7080 p8090;
save StataFiles/tables/table1w.dta, replace;
export excel using StataFiles/tables/table1w.xlsx, firstrow(variables) replace;


/*******************extracting table 2w: detailed statistics*/
forvalues year=1978/2015         
{;
use StataFiles/gperc_w_China.dta, clear;
keep if year==`year';
rename ythr ythr_`year';
rename ytop ytop_`year';
rename b b_`year';
keep p ythr_`year' ytop_`year' b_`year';
order p ythr_`year' ytop_`year' b_`year';
sort p;
save StataFiles/temp/g_percw_`year'.dta, replace;
clear;
};
use StataFiles/temp/g_percw_1978.dta;
forvalues year=1979/2015         
{;
merge 1:1 p using StataFiles/temp/g_percw_`year'.dta, nogen;
};
save Statafiles/tables/table2w.dta, replace;
export excel using Statafiles/tables/table2w.xlsx, firstrow(variables) replace;




/************(total China)exporting gperc in xlsx format for Gpinter copula simulations****/
forvalues year=1978/2015 
{;
/*****exporting gperc of non-fiscal income****/
/*****exporting year and average on top of tabulation*/
use StataFiles/gperc_ynf_China.dta, clear;
rename ythr thr;
keep if (p==0 | p==1000) & year==`year';
gen v1="year" if p==0;
replace v1="`year'" if p==1000;
gen v2="component" if p==0;
replace v2="ynf" if p==1000;
gen v3="average" if p==0;
keep v1 v2 v3;
export excel using Gpinter\Copulas\CopulasTabulations.xlsx, sheet(`year'ynf) sheetreplace cell(a1); 
/****exporting gperc thresholds and inverted Pareto coeff*/
use StataFiles/gperc_ynf_China.dta, clear;
keep if year==`year';
drop year;
replace p=abs(p)/100000;
keep if p==0.1 | p==0.2 | p==0.3 | p==0.4 | p==0.5 | p==0.6 | p==0.7 | p==0.8 | p==0.9 | (p>=0.95 & p<=0.9999);
rename ythr thr;
keep thr p b;
order p thr b;
export excel using Gpinter\Copulas\CopulasTabulations.xlsx, sheet(`year'ynf) sheetmodify cell(d1) firstrow(variables); 
use StataFiles/averages_China.dta, clear;
keep if year==`year';
keep ynf;
export excel using Gpinter\Copulas\CopulasTabulations.xlsx, sheet(`year'ynf) sheetmodify cell(c2); 
/*****exporting gperc of fiscal income****/
/*****exporting year and average on top of tabulation*/
use StataFiles/gperc_yf_China.dta, clear;
rename ythr thr;
keep if (p==0 | p==1000) & year==`year';
gen v1="year" if p==0;
replace v1="`year'" if p==1000;
gen v2="component" if p==0;
replace v2="yf" if p==1000;
gen v3="average" if p==0;
keep v1 v2 v3;
export excel using Gpinter\Copulas\CopulasTabulations.xlsx, sheet(`year'yf) sheetreplace cell(a1); 
/****exporting gperc thresholds and inverted Pareto coeff*/
use StataFiles/gperc_yf_China.dta, clear;
keep if year==`year';
drop year;
replace p=abs(p)/100000;
keep if p==0.1 | p==0.2 | p==0.3 | p==0.4 | p==0.5 | p==0.6 | p==0.7 | p==0.8 | p==0.9 | (p>=0.95 & p<=0.9999);
rename ythr thr;
keep thr p b;
order p thr b;
export excel using Gpinter\Copulas\CopulasTabulations.xlsx, sheet(`year'yf) sheetmodify cell(d1) firstrow(variables); 
use StataFiles/averages_China.dta, clear;
keep if year==`year';
keep yf;
export excel using Gpinter\Copulas\CopulasTabulations.xlsx, sheet(`year'yf) sheetmodify cell(c2); 
};

/************(urban China)exporting gperc in xlsx format for Gpinter copula simulations****/
forvalues year=1978/2015 
{;
/*****exporting gperc of non-fiscal income****/
/*****exporting year and average on top of tabulation*/
use StataFiles/gperc_ynf_UrbanChina.dta, clear;
rename ythr thr;
keep if (p==0 | p==1000) & year==`year';
gen v1="year" if p==0;
replace v1="`year'" if p==1000;
gen v2="component" if p==0;
replace v2="ynf" if p==1000;
gen v3="average" if p==0;
keep v1 v2 v3;
export excel using Gpinter\Copulas\CopulasTabulationsUrban.xlsx, sheet(`year'ynf) sheetreplace cell(a1); 
/****exporting gperc thresholds and inverted Pareto coeff*/
use StataFiles/gperc_ynf_UrbanChina.dta, clear;
keep if year==`year';
drop year;
replace p=abs(p)/100000;
keep if p==0.1 | p==0.2 | p==0.3 | p==0.4 | p==0.5 | p==0.6 | p==0.7 | p==0.8 | p==0.9 | (p>=0.95 & p<=0.9999);
rename ythr thr;
keep thr p b;
order p thr b;
export excel using Gpinter\Copulas\CopulasTabulationsUrban.xlsx, sheet(`year'ynf) sheetmodify cell(d1) firstrow(variables); 
use StataFiles/averages_China.dta, clear;
keep if year==`year';
gen ynfu=ynf*yfu/yf;
keep ynfu;
export excel using Gpinter\Copulas\CopulasTabulationsUrban.xlsx, sheet(`year'ynf) sheetmodify cell(c2); 
/*****exporting gperc of fiscal income****/
/*****exporting year and average on top of tabulation*/
use StataFiles/gperc_yf_UrbanChina.dta, clear;
rename ythr thr;
keep if (p==0 | p==1000) & year==`year';
gen v1="year" if p==0;
replace v1="`year'" if p==1000;
gen v2="component" if p==0;
replace v2="yf" if p==1000;
gen v3="average" if p==0;
keep v1 v2 v3;
export excel using Gpinter\Copulas\CopulasTabulationsUrban.xlsx, sheet(`year'yf) sheetreplace cell(a1); 
/****exporting gperc thresholds and inverted Pareto coeff*/
use StataFiles/gperc_yf_UrbanChina.dta, clear;
keep if year==`year';
drop year;
replace p=abs(p)/100000;
keep if p==0.1 | p==0.2 | p==0.3 | p==0.4 | p==0.5 | p==0.6 | p==0.7 | p==0.8 | p==0.9 | (p>=0.95 & p<=0.9999);
rename ythr thr;
keep thr p b;
order p thr b;
export excel using Gpinter\Copulas\CopulasTabulationsUrban.xlsx, sheet(`year'yf) sheetmodify cell(d1) firstrow(variables); 
use StataFiles/averages_China.dta, clear;
keep if year==`year';
keep yfu;
export excel using Gpinter\Copulas\CopulasTabulationsUrban.xlsx, sheet(`year'yf) sheetmodify cell(c2); 
};


/************(rural China)exporting gperc in xlsx format for Gpinter copula simulations****/
forvalues year=1978/2015 
{;
/*****exporting gperc of non-fiscal income****/
/*****exporting year and average on top of tabulation*/
use StataFiles/gperc_ynf_RuralChina.dta, clear;
rename ythr thr;
keep if (p==0 | p==1000) & year==`year';
gen v1="year" if p==0;
replace v1="`year'" if p==1000;
gen v2="component" if p==0;
replace v2="ynf" if p==1000;
gen v3="average" if p==0;
keep v1 v2 v3;
export excel using Gpinter\Copulas\CopulasTabulationsRural.xlsx, sheet(`year'ynf) sheetreplace cell(a1); 
/****exporting gperc thresholds and inverted Pareto coeff*/
use StataFiles/gperc_ynf_RuralChina.dta, clear;
keep if year==`year';
drop year;
replace p=abs(p)/100000;
keep if p==0.1 | p==0.2 | p==0.3 | p==0.4 | p==0.5 | p==0.6 | p==0.7 | p==0.8 | p==0.9 | (p>=0.95 & p<=0.9999);
rename ythr thr;
keep thr p b;
order p thr b;
export excel using Gpinter\Copulas\CopulasTabulationsRural.xlsx, sheet(`year'ynf) sheetmodify cell(d1) firstrow(variables); 
use StataFiles/averages_China.dta, clear;
keep if year==`year';
gen ynfr=ynf*yfr/yf;
keep ynfr;
export excel using Gpinter\Copulas\CopulasTabulationsRural.xlsx, sheet(`year'ynf) sheetmodify cell(c2); 
/*****exporting gperc of fiscal income****/
/*****exporting year and average on top of tabulation*/
use StataFiles/gperc_yf_RuralChina.dta, clear;
rename ythr thr;
keep if (p==0 | p==1000) & year==`year';
gen v1="year" if p==0;
replace v1="`year'" if p==1000;
gen v2="component" if p==0;
replace v2="yf" if p==1000;
gen v3="average" if p==0;
keep v1 v2 v3;
export excel using Gpinter\Copulas\CopulasTabulationsRural.xlsx, sheet(`year'yf) sheetreplace cell(a1); 
/****exporting gperc thresholds and inverted Pareto coeff*/
use StataFiles/gperc_yf_RuralChina.dta, clear;
keep if year==`year';
drop year;
replace p=abs(p)/100000;
keep if p==0.1 | p==0.2 | p==0.3 | p==0.4 | p==0.5 | p==0.6 | p==0.7 | p==0.8 | p==0.9 | (p>=0.95 & p<=0.9999);
rename ythr thr;
keep thr p b;
order p thr b;
export excel using Gpinter\Copulas\CopulasTabulationsRural.xlsx, sheet(`year'yf) sheetmodify cell(d1) firstrow(variables); 
use StataFiles/averages_China.dta, clear;
keep if year==`year';
keep yfr;
export excel using Gpinter\Copulas\CopulasTabulationsRural.xlsx, sheet(`year'yf) sheetmodify cell(c2); 
};



